/**************************************************************************
**
** Copyright (C) Computer Science Department, Worcester Polytechnic Institute,
**                           All rights reserved.
**
** FILE NAME: FtpSave.cpp
**
** DESCRIPTION: This program implements the methods of CControlOptionDlg 
**              
**
** AUTHOR: Zheng Zuo/Yubing Wang       March-2001
**
/**************************************************************************/



// FtpSave.cpp: implementation of the CFtpSave class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "RealTracker.h"
#include "FtpSave.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CFtpSave::CFtpSave()
{
    m_pInetSession = new CInternetSession(NULL, 1, PRE_CONFIG_INTERNET_ACCESS);
    m_pFtpConnection = NULL;
    m_pInternetFile = NULL;
}

CFtpSave::CFtpSave(LPCTSTR pstrServer, LPCTSTR pstrUserName, LPCTSTR pstrPassword)
{
    m_pInetSession = new CInternetSession(NULL, 1, PRE_CONFIG_INTERNET_ACCESS);

    try
    {
        m_pFtpConnection = m_pInetSession->GetFtpConnection(pstrServer, pstrUserName, pstrPassword);
	}
	catch (CInternetException* pEx)
	{
        // catch errors from WinINet
        //TCHAR szErr[1024];
        //if (pEx->GetErrorMessage(szErr, 1024))
        //    AfxMessageBox(szErr, MB_OK);

        pEx->Delete();
        m_pFtpConnection = NULL;
	}

    m_pInternetFile = NULL;
}

CFtpSave::~CFtpSave()
{
    if (m_pInternetFile)
    {
        m_pInternetFile->Close();
        delete m_pInternetFile;
    }
	if (m_pFtpConnection != NULL)
	{
		m_pFtpConnection->Close();
		delete m_pFtpConnection;
	}
	if (m_pInetSession != NULL)
	{
		m_pInetSession->Close();
		delete m_pInetSession;
	}
}

void CFtpSave::Connect(LPCTSTR pstrServer, LPCTSTR pstrUserName, LPCTSTR pstrPassword)
{
	if (m_pFtpConnection != NULL)
		m_pFtpConnection->Close();

    try
    {
        m_pFtpConnection = m_pInetSession->GetFtpConnection(pstrServer, pstrUserName, pstrPassword);
	}
	catch (CInternetException* pEx)
	{
        // catch errors from WinINet
        //TCHAR szErr[1024];
        //if (pEx->GetErrorMessage(szErr, 1024))
        //    AfxMessageBox(szErr, MB_OK);

        pEx->Delete();
        m_pFtpConnection = NULL;
	}
}

void CFtpSave::CloseConnection()
{
	if (m_pFtpConnection != NULL)
		m_pFtpConnection->Close();
    m_pFtpConnection = NULL;
}

BOOL CFtpSave::bConnected()
{
    return m_pFtpConnection != NULL;
}

void CFtpSave::Makedir(LPCTSTR pstrDirName)
{
    if (m_pFtpConnection == NULL)
        return;

    m_pFtpConnection->CreateDirectory(pstrDirName);
}

void CFtpSave::OpenFile(LPCTSTR pstrFileName)
{
    if (m_pFtpConnection == NULL)
        return;
    m_pInternetFile = m_pFtpConnection->OpenFile(pstrFileName, GENERIC_WRITE, FTP_TRANSFER_TYPE_ASCII);
}

void CFtpSave::Write(const void *lpBuf, UINT nCount)
{
    if (m_pFtpConnection == NULL || m_pInternetFile == NULL)
        return;
    try
    {
        m_pInternetFile->Write(lpBuf, nCount);
    }
    catch (CInternetException *pEx)
    {
        pEx->Delete();
        CloseFile();
    }
}

void CFtpSave::WriteString(LPCTSTR pstr)
{
    if (m_pFtpConnection == NULL || m_pInternetFile == NULL)
        return;

    try
    {
        m_pInternetFile->WriteString(pstr);
    }
    catch (CInternetException *pEx)
    {
        pEx->Delete();
        CloseFile();
    }
}

void CFtpSave::CloseFile()
{
    if (m_pFtpConnection == NULL || m_pInternetFile == NULL)
        return;
    try
    {
        m_pInternetFile->Close();
    }
    catch (CInternetException *pEx)
    {
        pEx->Delete();
        CloseConnection();
    }
    m_pInternetFile = NULL;
}

BOOL CFtpSave::bFileOpened()
{
    return m_pInternetFile != NULL;
}
