/**************************************************************************
**
** Copyright (C) Computer Science Department, Worcester Polytechnic Institute,
**                           All rights reserved.
**
** FILE NAME: MediaLog.cpp
**
** DESCRIPTION: This program implements the methods of CMediaLog class
**              
**
** AUTHOR: Zheng Zuo/Yubing Wang       March-2001
**
/**************************************************************************/



// MediaLog.cpp: implementation of the CMediaLog class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "RealTracker.h"
#include "MediaLog.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CMediaLog::CMediaLog()
{
    m_VQTest = NULL;
    m_MediaFileName = "";
    m_LogFileName = "";
    m_AudioStats = NULL;
    m_VideoStats = NULL;
    m_ServerInfo = NULL;
    m_VideoCodecName = NULL;

    m_NumSec = 0;
    m_curPointer = 0;
    m_NumPerSec = new int [];
    m_FrameIntervalBuf = new double [];
}

CMediaLog::CMediaLog(CVQTest *pVQTest)
{
    m_VQTest = pVQTest;
    m_MediaFileName = "";
    m_LogFileName = "";
    m_AudioStats = NULL;
    m_VideoStats = NULL;

    m_NumSec = 0;
    m_curPointer = 0;
    m_NumPerSec = new int [1200];               // for at most 20 minites
    m_FrameIntervalBuf = new double [36000];    // for 20 minutes, 30 frames / sec
}

CMediaLog::~CMediaLog()
{
    if (m_AudioStats != NULL)
        delete m_AudioStats;
    if (m_VideoStats != NULL)
        delete m_VideoStats;

    delete [] m_NumPerSec;
    delete [] m_FrameIntervalBuf;
}


CVQTest *CMediaLog::GetVQTest()                            { return m_VQTest; }
CString CMediaLog::GetMediaFileName()                      { return m_MediaFileName; }
CString CMediaLog::GetLogFileName()                        { return m_LogFileName; }
CMediaStatistics *CMediaLog::GetAudioStats()               { return m_AudioStats; }
CMediaStatistics *CMediaLog::GetVideoStats()               { return m_VideoStats; }
char *CMediaLog::GetServerInfo()                           { return m_ServerInfo; }
char *CMediaLog::GetVideoCodecName()                       { return m_VideoCodecName; }

void CMediaLog::SetVQTest(CVQTest *pVQTest)                    { m_VQTest = pVQTest; }
void CMediaLog::SetMediaFileName(CString MediaFileName)        { m_MediaFileName = MediaFileName; }
void CMediaLog::SetLogFileName(CString LogFileName)            { m_LogFileName = LogFileName; }  
void CMediaLog::SetAudioStats(CMediaStatistics *pAudioStats)   { m_AudioStats = pAudioStats; }   
void CMediaLog::SetVideoStats(CMediaStatistics *pVideoStats)   { m_VideoStats = pVideoStats; }   

void CMediaLog::InitAudioStats(int maxDataNum)
{
    if (m_AudioStats == NULL)
        m_AudioStats = new CMediaStatistics(maxDataNum);
    else
        m_AudioStats->Init(maxDataNum);
}

void CMediaLog::InitVideoStats(int maxDataNum)
{
    if (m_VideoStats == NULL)
        m_VideoStats = new CMediaStatistics(maxDataNum);
    else
        m_VideoStats->Init(maxDataNum);

    m_NumSec = 0;
    m_curPointer = 0;
}

void CMediaLog::AddAudioStatsData(VQData *pData)
{
    m_AudioStats->AddVQData(pData);
}

void CMediaLog::AddVideoStatsData(VQData *pData)
{
    m_ServerInfo = pData->ServerInfo;
    m_VideoCodecName = pData->VideoCodecName;
    m_VideoStats->AddVQData(pData);
}

void CMediaLog::AddAudioJitterData(VQJitter *pJitter)
{
    m_AudioStats->AddVQJitter(pJitter);
}

void CMediaLog::AddVideoJitterData(VQJitter *pJitter)
{
    m_VideoStats->AddVQJitter(pJitter);
}

void CMediaLog::AddInterval(int n, double *intervals)
{
    return;
/*    if (m_NumSec >= 1200 || m_curPointer+n > 36000)
        return;
    m_NumPerSec[m_NumSec] = n;
    m_NumSec ++;
    memcpy(&m_FrameIntervalBuf[m_curPointer], intervals, sizeof(double)*n);
    m_curPointer += n;*/
}

