/**************************************************************************
**
** Copyright (C) Computer Science Department, Worcester Polytechnic Institute,
**                           All rights reserved.
**
** FILE NAME: MediaStatistics.cpp
**
** DESCRIPTION: This program implements the methods of CMediaStatistics class
**              
**
** AUTHOR: Zheng Zuo/Yubing Wang       March-2001
**
/**************************************************************************/



// MediaStatistics.cpp: implementation of the CMediaStatistics class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "RealTracker.h"
#include "MediaStatistics.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CMediaStatistics::CMediaStatistics()
{
    m_VQDataNum = 0;
    m_maxVQDataNum = 0;
    m_VQDataHead = new VQDataLink;
    m_VQDataTail = m_VQDataHead;
    m_VQDataTail->next = NULL;

    m_VQJitterNum = 0;
    m_maxVQJitterNum = 0;
    m_VQJitterHead = new VQJitterLink;
    m_VQJitterTail = m_VQJitterHead;
    m_VQJitterTail->next = NULL;
}

CMediaStatistics::CMediaStatistics(int maxDataNum)
{
    int i;
    VQDataLink *p;
    VQJitterLink *q;

    m_VQDataNum = 0;
    m_maxVQDataNum = maxDataNum;
//    m_VQData = new VQData [m_maxVQDataNum];
    m_VQDataHead = new VQDataLink;
    m_VQDataTail = m_VQDataHead;
    for (i=0; i<m_maxVQDataNum; i++)
    {
        p = new VQDataLink;
        m_VQDataTail->next = p;
        m_VQDataTail = p;
    }
    m_VQDataTail->next = NULL;
    m_VQDataTail = m_VQDataHead;

    m_VQJitterNum = 0;
    m_maxVQJitterNum = maxDataNum / 60;
//    m_VQJitter = new VQJitter [m_maxVQJitterNum];
    m_VQJitterHead = new VQJitterLink;
    m_VQJitterTail = m_VQJitterHead;
    for (i=0; i<m_maxVQJitterNum; i++)
    {
        q = new VQJitterLink;
        m_VQJitterTail->next = q;
        m_VQJitterTail = q;
    }
    m_VQJitterTail->next = NULL;
    m_VQJitterTail = m_VQJitterHead;
}

CMediaStatistics::~CMediaStatistics()
{
    VQDataLink *p1, *p2;
    VQJitterLink *q1, *q2;

    p1 = m_VQDataHead;
    while (p1)
    {
        p2 = p1->next;
        delete p1;
        p1 = p2;
    }

    q1 = m_VQJitterHead;
    while (q1)
    {
        q2 = q1->next;
        delete q1;
        q1 = q2;
    }
}

int CMediaStatistics::GetVQDataNum()
{
    return m_VQDataNum;
}

VQData *CMediaStatistics::GetVQDataFirst(VQDataLink *&pVQDataLink)
{
    pVQDataLink = m_VQDataHead->next;
    return pVQDataLink ? &pVQDataLink->data : NULL;
}

VQData *CMediaStatistics::GetVQDataNext(VQDataLink *&pVQDataLink)
{
    ASSERT(pVQDataLink != NULL);
    pVQDataLink = (pVQDataLink == m_VQDataTail) ? NULL : pVQDataLink->next;
    return pVQDataLink ? &pVQDataLink->data : NULL;
}

int CMediaStatistics::GetVQJitterNum()
{
    return m_VQJitterNum;
}

VQJitter *CMediaStatistics::GetVQJitterFirst(VQJitterLink *&pVQJitterLink)
{
    pVQJitterLink = m_VQJitterHead->next;
    return pVQJitterLink ? &pVQJitterLink->data : NULL;
}

VQJitter *CMediaStatistics::GetVQJitterNext(VQJitterLink *&pVQJitterLink)
{
    ASSERT(pVQJitterLink != NULL);
    pVQJitterLink = (pVQJitterLink == m_VQJitterTail) ? NULL : pVQJitterLink->next;
    return pVQJitterLink ? &pVQJitterLink->data : NULL;
}

void CMediaStatistics::Init(int maxVQDataNum)
{
    m_VQDataNum = 0;
    if (m_VQDataHead->next == NULL || m_maxVQDataNum < maxVQDataNum)
    {
        VQDataLink *p;
        while (m_VQDataTail->next)
            m_VQDataTail = m_VQDataTail->next;
        for (int i=m_maxVQDataNum; i<maxVQDataNum; i++)
        {
            p = new VQDataLink;
            m_VQDataTail->next = p;
            m_VQDataTail = p;
        }
        m_VQDataTail->next = NULL;
        m_maxVQDataNum = maxVQDataNum;
    }
    m_VQDataTail = m_VQDataHead;

    int maxVQJitterNum = maxVQDataNum / 60 + 1;

    m_VQJitterNum = 0;
    if (m_VQJitterHead->next == NULL || m_maxVQJitterNum < maxVQJitterNum)
    {
        VQJitterLink *p;
        while (m_VQJitterTail->next)
            m_VQJitterTail = m_VQJitterTail->next;
        for (int i=m_maxVQJitterNum; i<maxVQJitterNum; i++)
        {
            p = new VQJitterLink;
            m_VQJitterTail->next = p;
            m_VQJitterTail = p;
        }
        m_VQJitterTail->next = NULL;
        m_maxVQJitterNum = maxVQJitterNum;
    }
    m_VQJitterTail = m_VQJitterHead;
}

void CMediaStatistics::AddVQData(VQData *pVQData)
{
    if (m_VQDataNum == m_maxVQDataNum)
    {
        VQDataLink *p = new VQDataLink;
        p->next = NULL;
        m_VQDataTail->next = p;
        m_maxVQDataNum ++;
    }
    m_VQDataTail = m_VQDataTail->next;
    memcpy(&m_VQDataTail->data, pVQData, sizeof(VQData));
    m_VQDataNum ++;
}

void CMediaStatistics::AddVQJitter(VQJitter *pVQJitter)
{
    if (m_VQJitterNum == m_maxVQJitterNum)
    {
        VQJitterLink *p = new VQJitterLink;
        p->next = NULL;
        m_VQJitterTail->next = p;
        m_maxVQJitterNum ++;
    }
    m_VQJitterTail = m_VQJitterTail->next;
    memcpy(&m_VQJitterTail->data, pVQJitter, sizeof(VQJitter));
    m_VQJitterNum ++;
}

