/**************************************************************************
**
** Copyright (C) Computer Science Department, Worcester Polytechnic Institute,
**                           All rights reserved.
**
** FILE NAME: RealTrackerView.h
**
** DESCRIPTION: This class defines the interface between user and RealTracker,
**              including the interaction control and statistics data delivery
**              
**
** AUTHOR: Zheng Zuo/Yubing Wang        March-2001
**
/**************************************************************************/



// RealTrackerView.h : interface of the CRealTrackerView class
//
/////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_REALTRACKERVIEW_H__1BC634D9_14BC_4383_A190_2A957288EAD5__INCLUDED_)
#define AFX_REALTRACKERVIEW_H__1BC634D9_14BC_4383_A190_2A957288EAD5__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "SocketX.h"
#include "FtpSave.h"
#include "QualityInputDlg.h"
#include "UserInfoDlg.h"

class CVQTest;
class CRealTrackerDoc;
class CStatsDlg;

class CRealTrackerView : public CListView
{
protected: // create from serialization only
	CRealTrackerView();
	DECLARE_DYNCREATE(CRealTrackerView)

// Attributes
public:
	CRealTrackerDoc* GetDocument();

// Operations
public:

// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CRealTrackerView)
	public:
	virtual void OnDraw(CDC* pDC);  // overridden to draw this view
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	protected:
	virtual void OnInitialUpdate(); // called first time after construct
	//}}AFX_VIRTUAL
	afx_msg LRESULT OnVQAction(WPARAM wParam, LPARAM lParam);
    afx_msg void OnUpdateProgress(CCmdUI *pCmdUI);
    afx_msg void OnUpdateTimeLine(CCmdUI *pCmdUI);

// Implementation
public:
	virtual ~CRealTrackerView();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

protected:

// Generated message map functions
protected:
	//{{AFX_MSG(CRealTrackerView)
	afx_msg void OnTimer(UINT nIDEvent);
	afx_msg void OnControlPlay();
	afx_msg void OnControlStop();
	afx_msg void OnControlOption();
	afx_msg void OnUpdateControlPlay(CCmdUI* pCmdUI);
	afx_msg void OnUpdateControlStop(CCmdUI* pCmdUI);
	afx_msg void OnFileUser();
	afx_msg void OnViewStat();
	afx_msg void OnUpdateViewStat(CCmdUI* pCmdUI);
	afx_msg void OnFileSavelog();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()

private:
    BOOL m_bInitialized;

    CStatsDlg *m_StatsDlg;
    BOOL m_StatsDlgIsVisable;

    double m_SizeRatio;

    int m_nProgListNum;
    CString *m_ProgDspt;
    CString *m_ProgList;
    int m_nCurPlayIndex;

    UINT m_nTimer;

    Preference m_Pref;
    AdvancedPreference m_AdvPref;
    int m_nQuaValue;

    BOOL m_bSaveToFile;
    CString m_SaveToDir;

    CVQTest *m_VQTest;

    BOOL m_bPlaying;
    BOOL m_bCurRunning;
    BOOL m_bNextRunning;
    BOOL m_bOnBegined;
    int m_TimerValue;

    SYSTEMTIME m_st;     // end time of a clip, used to form file name
    CString m_StartTime;
    CString m_EndTime;   // used to output

    int m_ProgressLine;
    CString m_TimeLine;

public:
    int GetProgListNum();
    CString *GetProgDspt();
    CString *GetProgList();
    int GetCurPlayIndex();
    void ShowProgressBarAndTimeLine(int Prog, char *TimeLine);
    CVQTest *GetVQTest();

    CStatsDlg *GetStatsDlg();
    void HideStatsDlg();
    BOOL StatsDlgIsVisable();

    void StartPlayOne();
    void FinishPlayOne();

    BOOL MailResult(CString smtpserver, CString username, CString useraddr, BOOL bPlayed);
    BOOL FtpResult(CString server, CString user, CString passwd, CString dir, BOOL bPlayed);
    BOOL SaveResult(CString dir, BOOL bPlayed);

    BOOL OutputLog(CSocketX *pSocket, CFtpSave *pFtp, FILE *fp, BOOL bPlayed);
    BOOL OutputUserInfo(CSocketX *pSocket, CFtpSave *pFtp, FILE *fp);
    BOOL OutputResultData(CSocketX *pSocket, CFtpSave *pFtp, FILE *fp);
    BOOL OutputVideoQuality(CSocketX *pSocket, CFtpSave *pFtp, FILE *fp);
    BOOL OutputOneLine(CSocketX *pSocket, CFtpSave *pFtp, FILE *fp, CString szMessage);
};

#ifndef _DEBUG  // debug version in RealTrackerView.cpp
inline CRealTrackerDoc* CRealTrackerView::GetDocument()
   { return (CRealTrackerDoc*)m_pDocument; }
#endif

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_REALTRACKERVIEW_H__1BC634D9_14BC_4383_A190_2A957288EAD5__INCLUDED_)
