/**************************************************************************
**
** Copyright (C) Computer Science Department, Worcester Polytechnic Institute,
**                           All rights reserved.
**
** FILE NAME: RealListView.cpp
**
** DESCRIPTION: This program implements the methods of CRealListView class
**              
**
** AUTHOR: Zheng Zuo/Yubing Wang        March-2001
**
/**************************************************************************/


// RealListView.cpp : implementation file
//

#include "stdafx.h"
#include "RealData.h"
#include "RealListView.h"
#include "RealDataView.h"
#include "ShowLogWnd.h"
#include "ShowLogDoc.h"
#include "ShowLogView.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

static int CALLBACK MyCompareProc(LPARAM lParam1, LPARAM lParam2, LPARAM lParamSort);

/////////////////////////////////////////////////////////////////////////////
// CRealListView

IMPLEMENT_DYNCREATE(CRealListView, CListView)

CRealListView::CRealListView()
{
    m_bInitialized = FALSE;
    m_numberOfListViewColumns = 0;
    m_nCurItemIndex = -1;
}

CRealListView::~CRealListView()
{
}

CRealDataDoc *CRealListView::GetDocument()
{
    return ((CRealDataView *) GetParent()->GetParent())->GetDocument();
}


BEGIN_MESSAGE_MAP(CRealListView, CListView)
	//{{AFX_MSG_MAP(CRealListView)
	ON_NOTIFY_REFLECT(LVN_COLUMNCLICK, OnColumnclick)
	ON_NOTIFY_REFLECT(NM_DBLCLK, OnDblclk)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CRealListView drawing

void CRealListView::OnDraw(CDC* pDC)
{
	CDocument* pDoc = GetDocument();
	// TODO: add draw code here
}

/////////////////////////////////////////////////////////////////////////////
// CRealListView diagnostics

#ifdef _DEBUG
void CRealListView::AssertValid() const
{
	CListView::AssertValid();
}

void CRealListView::Dump(CDumpContext& dc) const
{
	CListView::Dump(dc);
}
#endif //_DEBUG

/////////////////////////////////////////////////////////////////////////////
// CRealListView message handlers

BOOL CRealListView::PreCreateWindow(CREATESTRUCT& cs) 
{
    cs.style |= LVS_SHOWSELALWAYS | LVS_REPORT;

    return CListView::PreCreateWindow(cs);
}

void CRealListView::OnInitialUpdate() 
{
	CListView::OnInitialUpdate();
	
    if (m_bInitialized)
    {
        CListCtrl& theListCtrl = GetListCtrl();
        theListCtrl.DeleteAllItems();
        m_nCurItemIndex = -1;
        return;
    }

    m_bInitialized = TRUE;
	    
    //((CMainFrame*)AfxGetMainWnd())->m_pListView = this;
    InitializeListView();
}

void CRealListView::OnColumnclick(NMHDR* pNMHDR, LRESULT* pResult) 
{
    NM_LISTVIEW* pNMListView = (NM_LISTVIEW*)pNMHDR;

    *pResult = 0;

    if (m_nSortDirect == 0 || m_nSortedColumn != pNMListView->iSubItem)   // none order or change a column
    {
        m_nSortedColumn = pNMListView->iSubItem;
        m_nSortDirect = 1;
    }
    else  // change the sort method, keep this column
        m_nSortDirect = (m_nSortDirect == 1 ? 2 : 1);

    CListCtrl& theListCtrl = GetListCtrl();

    // Sort the list view items using my callback procedure.
    theListCtrl.SortItems(MyCompareProc, (LPARAM) this);
	
}

void CRealListView::OnDblclk(NMHDR* pNMHDR, LRESULT* pResult) 
{
    NM_LISTVIEW* pNMListView = (NM_LISTVIEW*)pNMHDR;
	
    *pResult = 0;

    CListCtrl& theListCtrl = GetListCtrl();
    if (pNMListView->iItem == -1)
        return;

    int subIndex = theListCtrl.GetItemData(pNMListView->iItem);
    CRealTraceData *pData = GetDocument()->GetRealTraceData();
    //CRealData* pDataItem = pData->GetSubItemData(m_nCurItemIndex, subIndex);
    //CString filename = pData->GetRootDir() + "\\" + pData->GetItemName(m_nCurItemIndex) + "\\" + pDataItem->FileName;
    CString filename = pData->GetSubItemPath(m_nCurItemIndex, subIndex);

    CShowLogWnd *pWnd = new CShowLogWnd;
	CCreateContext context;
	context.m_pNewViewClass   = RUNTIME_CLASS(CShowLogView);
	context.m_pCurrentDoc     = new CShowLogDoc(filename);
	context.m_pNewDocTemplate = NULL;
	context.m_pLastView       = NULL;
	context.m_pCurrentFrame   = NULL;
    pWnd->LoadFrame(IDR_SHOWLOG, WS_OVERLAPPEDWINDOW | WS_MAXIMIZE | FWS_ADDTOTITLE, NULL, &context);
    pWnd->InitialUpdateFrame(context.m_pCurrentDoc, TRUE);
}

/////////////////////////////////////////////////////////////////////////////
// CRealListView operations

void CRealListView::InitializeListView()
{
	CListCtrl& theListCtrl = GetListCtrl();

    theListCtrl.SetRedraw(FALSE); 
	
	//For the style LVS_EX_FULLROWSELECT, you'll need the following, depending on the OS:
	//Windows NT: Requires version 5.0 or later (or version 4.0 with Internet Explorer 3.0 and later).. 
	//Windows: Requires Windows 98 (or Windows 95 with Internet Explorer 3.0 or later). 
	//Otherwise, you'll need to do ownerdrawn stuff. In that case, see the MFC ROWLIST sample.
	DWORD dwExStyle = LVS_EX_FULLROWSELECT;

	theListCtrl.SendMessage(LVM_SETEXTENDEDLISTVIEWSTYLE, (WPARAM)dwExStyle, (LPARAM)dwExStyle);
	COLORREF crYellow = RGB(240, 240, 200); //light yellow
	theListCtrl.SetBkColor(crYellow);
	theListCtrl.SetTextBkColor(crYellow);

    m_numberOfListViewColumns = sizeof(szColumnHead) / SZCOLUMNHEAD_LENGTH;
    for (int i=0; i<m_numberOfListViewColumns; i++)
	    theListCtrl.InsertColumn(i, szColumnHead[i]);

    for(i = 0; i< m_numberOfListViewColumns; i++)
		theListCtrl.SetColumnWidth(i, LVSCW_AUTOSIZE_USEHEADER); 

	//if any items in the list view, then take the quote from the first item
	if (theListCtrl.GetItemCount() > 0) 
	{
		//Select the first item in the list view:
		theListCtrl.SetItemState(0, LVIS_SELECTED, LVIS_SELECTED);
        theListCtrl.EnsureVisible(0, FALSE);
	}

	theListCtrl.SetRedraw(TRUE);
	theListCtrl.Invalidate(); 
}

void CRealListView::ChangeListView(int newItemIndex)
{
    if (m_nCurItemIndex == newItemIndex)
        return;

    CListCtrl& theListCtrl = GetListCtrl();
    theListCtrl.DeleteAllItems();
    m_nCurItemIndex = newItemIndex;

    CRealTraceData *pData = GetDocument()->GetRealTraceData();
    if (newItemIndex < 0 || newItemIndex > pData->GetItemNum())
        return;

    int num = pData->GetSubItemNum(newItemIndex);
    CRealData *pDataItem;
    CString szItemText;
    int hh, mm, ss;
    for (int i=0; i<num; i++)
    {
        pDataItem = pData->GetSubItemData(newItemIndex, i);
	    theListCtrl.InsertItem(i, pDataItem->FileName);
        theListCtrl.SetItemData(i, (DWORD) i);

	    theListCtrl.SetItemText(i, 1, pDataItem->Location);

        theListCtrl.SetItemText(i, 2, pDataItem->IPAddress);

        theListCtrl.SetItemText(i, 3, szCPUType[pDataItem->CPUType]);

        szItemText.Format("%d", pDataItem->Memory);
	    theListCtrl.SetItemText(i, 4, szItemText);

        theListCtrl.SetItemText(i, 5, szOSType[pDataItem->OSType]);

        theListCtrl.SetItemText(i, 6, szNetConfig[pDataItem->NetConfig]);

        //theListCtrl.SetItemText(i, 7, pDataItem->Time);
        hh = pDataItem->Time / 3600;
        mm = (pDataItem->Time % 3600) / 60;
        ss = (pDataItem->Time % 3600) % 60;
        szItemText.Format("%02d:%02d:%02d", hh, mm, ss);
        theListCtrl.SetItemText(i, 7, szItemText);

        szItemText.Format("%d", pDataItem->VideoIndex);
	    theListCtrl.SetItemText(i, 8, szItemText);

        theListCtrl.SetItemText(i, 9, pDataItem->VideoName);

        theListCtrl.SetItemText(i, 10, pDataItem->RealServerInfo);

        theListCtrl.SetItemText(i, 11, pDataItem->RealCodec);

        theListCtrl.SetItemText(i, 12, szTransProtocol[pDataItem->TransProtocol]);

        szItemText.Format("%.2lf", pDataItem->AvgBandWidth);
        theListCtrl.SetItemText(i, 13, szItemText);

        szItemText.Format("%.2lf", pDataItem->AvgFrameRate);
	    theListCtrl.SetItemText(i, 14, szItemText);

        szItemText.Format("%.2lf", pDataItem->AvgJitter);
	    theListCtrl.SetItemText(i, 15, szItemText);

        szItemText.Format("%.2lf", pDataItem->AvgCpuUsage);
	    theListCtrl.SetItemText(i, 16, szItemText);

        szItemText.Format("%.2lf", pDataItem->Quality);
        theListCtrl.SetItemText(i, 17, szItemText);

        szItemText.Format("%d", pDataItem->CodedFR);
        theListCtrl.SetItemText(i, 18, szItemText);

        szItemText.Format("%d", pDataItem->CodedBW);
        theListCtrl.SetItemText(i, 19, szItemText);

        szItemText.Format("%d", pDataItem->FrameLost);
        theListCtrl.SetItemText(i, 20, szItemText);

        szItemText.Format("%d", pDataItem->DataNum);
        theListCtrl.SetItemText(i, 21, szItemText);
    }

    m_nSortedColumn = -1;
    m_nSortDirect = 0;
}

void CRealListView::AddToListView(CRealData *pDataItem)
{
    CRealTraceData *pData = GetDocument()->GetRealTraceData();

    CListCtrl& theListCtrl = GetListCtrl();

    theListCtrl.SetRedraw(FALSE); 

    int num = theListCtrl.GetItemCount();
    int i = theListCtrl.InsertItem(num, pDataItem->FileName);
    theListCtrl.SetItemData(i, (DWORD) i);

	theListCtrl.SetItemText(i, 1, pDataItem->Location);

    theListCtrl.SetItemText(i, 2, pDataItem->IPAddress);

    theListCtrl.SetItemText(i, 3, szCPUType[pDataItem->CPUType]);

    CString szItemText;
    szItemText.Format("%d", pDataItem->Memory);
	theListCtrl.SetItemText(i, 4, szItemText);

    theListCtrl.SetItemText(i, 5, szOSType[pDataItem->OSType]);

    theListCtrl.SetItemText(i, 6, szNetConfig[pDataItem->NetConfig]);

    //theListCtrl.SetItemText(i, 7, pDataItem->Time);
    int hh = pDataItem->Time / 3600;
    int mm = (pDataItem->Time % 3600) / 60;
    int ss = (pDataItem->Time % 3600) % 60;
    szItemText.Format("%02d:%02d:%02d", hh, mm, ss);
    theListCtrl.SetItemText(i, 7, szItemText);

    szItemText.Format("%d", pDataItem->VideoIndex);
	theListCtrl.SetItemText(i, 8, szItemText);

    theListCtrl.SetItemText(i, 9, pDataItem->VideoName);

    theListCtrl.SetItemText(i, 10, pDataItem->RealServerInfo);

    theListCtrl.SetItemText(i, 11, pDataItem->RealCodec);

    theListCtrl.SetItemText(i, 12, szTransProtocol[pDataItem->TransProtocol]);

    szItemText.Format("%.2lf", pDataItem->AvgBandWidth);
    theListCtrl.SetItemText(i, 13, szItemText);

    szItemText.Format("%.2lf", pDataItem->AvgFrameRate);
	theListCtrl.SetItemText(i, 14, szItemText);

    szItemText.Format("%.2lf", pDataItem->AvgJitter);
	theListCtrl.SetItemText(i, 15, szItemText);

    szItemText.Format("%.2lf", pDataItem->AvgCpuUsage);
	theListCtrl.SetItemText(i, 16, szItemText);

    szItemText.Format("%.2lf", pDataItem->Quality);
    theListCtrl.SetItemText(i, 17, szItemText);

    szItemText.Format("%d", pDataItem->CodedFR);
    theListCtrl.SetItemText(i, 18, szItemText);

    szItemText.Format("%d", pDataItem->CodedBW);
    theListCtrl.SetItemText(i, 19, szItemText);

    szItemText.Format("%d", pDataItem->FrameLost);
    theListCtrl.SetItemText(i, 20, szItemText);

    szItemText.Format("%d", pDataItem->DataNum);
    theListCtrl.SetItemText(i, 21, szItemText);

    m_nSortedColumn = -1;
    m_nSortDirect = 0;

	theListCtrl.SetRedraw(TRUE);
	theListCtrl.Invalidate(); 
}


inline int CompareInt(int p1, int p2)           { return (p1 < p2) ? -1 : ((p1 == p2) ? 0 : 1); }

inline int CompareDouble(double p1, double p2)  { return (p1 < p2) ? -1 : ((p1 == p2) ? 0 : 1); }

static int CALLBACK MyCompareProc(LPARAM lParam1, LPARAM lParam2, LPARAM lParamSort)
{
    CRealListView* pListView = (CRealListView *) lParamSort;
    CRealTraceData *pData = pListView->GetDocument()->GetRealTraceData();

    int index1 = lParam1;
    int index2 = lParam2;
    CRealData* pDataItem1 = pData->GetSubItemData(pListView->m_nCurItemIndex, index1);
    CRealData* pDataItem2 = pData->GetSubItemData(pListView->m_nCurItemIndex, index2);
    BOOL bAscending = pListView->m_nSortDirect == 1;
    int iColumn = pListView->m_nSortedColumn;

    int result = 0;
    switch (iColumn)
    {
        case 0:     // FileName
            result = pDataItem1->FileName.Compare(pDataItem2->FileName);
            break;

        case 1:     // Location
            result = pDataItem1->Location.CompareNoCase(pDataItem2->Location);
            break;

        case 2:     // IPAddress
            result = pDataItem1->IPAddress.Compare(pDataItem2->IPAddress);
            break;

        case 3:     // CPUType
            result = CompareInt(pDataItem1->CPUType, pDataItem2->CPUType);
            break;

        case 4:     // Memory
            result = CompareInt(pDataItem1->Memory, pDataItem2->Memory);
            break;

        case 5:     // OSType
            result = CompareInt(pDataItem1->OSType, pDataItem2->OSType);
            break;

        case 6:     // NetConfig
            result = CompareInt(pDataItem1->NetConfig, pDataItem2->NetConfig);
            break;

        case 7:     // Time
            //result = pDataItem1->Time.Compare(pDataItem2->Time);
            result = CompareInt(pDataItem1->Time, pDataItem2->Time);
            break;

        case 8:     // VideoIndex
            result = CompareInt(pDataItem1->VideoIndex, pDataItem2->VideoIndex);
            break;

        case 9:     // VideoName
            result = pDataItem1->VideoName.Compare(pDataItem2->VideoName);
            break;

        case 10:    // RealServerInfo    
            result = pDataItem1->RealServerInfo.Compare(pDataItem2->RealServerInfo);
            break;

        case 11:    // RealCodec
            result = pDataItem1->RealCodec.Compare(pDataItem2->RealCodec);
            break;

        case 12:    // TransProtocol
            result = CompareInt(pDataItem1->TransProtocol, pDataItem2->TransProtocol);
            break;

        case 13:    // AvgBandWidth
            result = CompareDouble(pDataItem1->AvgBandWidth, pDataItem2->AvgBandWidth);
            break;

        case 14:    // AvgFrameRate
            result = CompareDouble(pDataItem1->AvgFrameRate, pDataItem2->AvgFrameRate);
            break;

        case 15:    // AvgJitter
            result = CompareDouble(pDataItem1->AvgJitter, pDataItem2->AvgJitter);
            break;

        case 16:    // AvgCpuUsage
            result = CompareDouble(pDataItem1->AvgCpuUsage, pDataItem2->AvgCpuUsage);
            break;

        case 17:    // Quality
            result = CompareDouble(pDataItem1->Quality, pDataItem2->Quality);
            break;

        case 18:    // CodedFR
            result = CompareInt(pDataItem1->CodedFR, pDataItem2->CodedFR);
            break;
        
		case 19:    // CodedBW
            result = CompareInt(pDataItem1->CodedBW, pDataItem2->CodedBW);
            break;

        case 20:    // FrameLost
            result = CompareInt(pDataItem1->FrameLost, pDataItem2->FrameLost);
            break;

        case 21:    // FrameLost
            result = CompareInt(pDataItem1->DataNum, pDataItem2->DataNum);
            break;

        default:
            result = 0;
            break;
    }

    return bAscending ? result : -result;
}

void CRealListView::OnCdfFrAll() 
{
	// TODO: Add your command handler code here
	int NumItem;
	int index;
	int index1;
	int StartItem = 0;
	int sum = 0;
	int sum1 = 0;
	double FrRange = 0.5;

	int FrCount[60];
	double FrPerc[60];

    CFileDialog fDlg(FALSE, "csv", NULL, OFN_HIDEREADONLY | OFN_OVERWRITEPROMPT, 
                     "csv files (*.csv)|*.csv|all files (*.*)|*.*||", AfxGetApp()->GetMainWnd());

	
    if (fDlg.DoModal() != IDOK)
        return;

	CString file = fDlg.GetPathName();
    FILE *fp;
    fp = fopen(file, "w");
    if (fp == NULL)
        return;

	for (index = 0; index < 60; index ++)
	{
		FrCount[index] = 0;
		FrPerc[index] = 0.0;
	}

	CRealTraceData *pData = GetDocument()->GetRealTraceData();    
	NumItem = pData->GetSubItemNum(m_nCurItemIndex);
	

	for(index = 0; index < NumItem; index++)
	{
		CRealData* pDataItem = pData->GetSubItemData(m_nCurItemIndex, index);

		if (pDataItem->AvgFrameRate > 0)
		FrCount[(int)(pDataItem->AvgFrameRate*2)] ++;
    }

	  
	 for (index = 0; index < 52; index ++)
	 {
		sum += FrCount[index];
	 }

	 for (index = 0; index < 52; index ++)
	 {
        
        sum1 = 0;
        for( index1 = 0; index1 <= index; index1++)
		{
			sum1 += FrCount[index1];
		}
		FrPerc[index] = sum > 0 ? (double)sum1/sum:0.0;
	 }	

  
	for (index = 0; index < 52; index++)
	{
		fprintf(fp,"%f, %f\n", FrRange,FrPerc[index]);  
		FrRange += 0.5;
	}
	fclose (fp);
}

void CRealListView::OnCdfFrSelected() 
{
	// TODO: Add your command handler code here
	int index;
    int index1;
	int StartItem = 0;
	int sum = 0;
	int sum1 = 0;
	double FrRange = 0.5;

	int FrCount[60];
	double FrPerc[60];

    CFileDialog fDlg(FALSE, "csv", NULL, OFN_HIDEREADONLY | OFN_OVERWRITEPROMPT, 
                     "csv files (*.csv)|*.csv|all files (*.*)|*.*||", AfxGetApp()->GetMainWnd());

	
    if (fDlg.DoModal() != IDOK)
        return;

	CString file = fDlg.GetPathName();
    FILE *fp;
    fp = fopen(file, "w");
    if (fp == NULL)
        return;

	for (index = 0; index < 60; index ++)
	{
		FrCount[index] = 0;
		FrPerc[index] = 0.0;
	}

	CRealTraceData *pData = GetDocument()->GetRealTraceData();    
    CListCtrl& theListCtrl = GetListCtrl();
	
	
	POSITION pos = theListCtrl.GetFirstSelectedItemPosition();
	
    while (pos)
    {
      int nItem = theListCtrl.GetNextSelectedItem(pos);
	  int nSubItem = theListCtrl.GetItemData(nItem);	
	  CRealData* pDataItem = pData->GetSubItemData(m_nCurItemIndex, nSubItem);
	  if (pDataItem->AvgFrameRate > 0)
	  FrCount[(int)(pDataItem->AvgFrameRate*2)] ++;
    }

	for (index = 0; index < 52; index ++)
	 {
		sum += FrCount[index];
	 }

	 for (index = 0; index < 52; index ++)
	 {
        
        sum1 = 0;
        for( index1 = 0; index1 <= index; index1++)
		{
			sum1 += FrCount[index1];
		}
		FrPerc[index] = sum > 0 ? (double)sum1/sum:0.0;
	 }	

  
	for (index = 0; index < 52; index++)
	{
		fprintf(fp,"%f, %f\n", FrRange,FrPerc[index]);  
		FrRange += 0.5;
	}
	fclose (fp);
}

void CRealListView::OnCdfBwAll() 
{
    CRealListView::CdfBwAllAndSelected(FALSE);
}

void CRealListView::OnCdfBwSelected() 
{
    CRealListView::CdfBwAllAndSelected(TRUE);
}

void CRealListView::CdfBwAllAndSelected(int bSelected)
{
    int index;
    int StartItem = 0;
    int sum = 0;
    int sum1 = 0;

    double BWRange = 12.5 * 1024;
    int BWNum = 41;
    int BWCount[60];
    double BWPerc[60];
    double BW;

    CFileDialog fDlg(FALSE, "csv", NULL, OFN_HIDEREADONLY | OFN_OVERWRITEPROMPT, "csv files (*.csv)|*.csv|all files (*.*)|*.*||", AfxGetApp()->GetMainWnd());


    if (fDlg.DoModal() != IDOK)
        return;

    CString file = fDlg.GetPathName();
    FILE *fp;
    fp = fopen(file, "w");
    if (fp == NULL)
        return;

    for (index = 0; index < BWNum; index ++)
    {
        BWCount[index] = 0;
        BWPerc[index] = 0.0;
    }

    CRealTraceData *pData = GetDocument()->GetRealTraceData();
    if (! bSelected)
    {
        int NumItem = pData->GetSubItemNum(m_nCurItemIndex);
        for(index = 0; index < NumItem; index++)
        {
            CRealData* pDataItem = pData->GetSubItemData(m_nCurItemIndex, index);
            if (pDataItem->AvgFrameRate > 0)
                BWCount[(int) (pDataItem->AvgBandWidth / BWRange)] ++;
        }
    }
    else
    {
        CListCtrl& theListCtrl = GetListCtrl();
        POSITION pos = theListCtrl.GetFirstSelectedItemPosition();
        int nItem, nSubItem;
        CRealData* pDataItem;
        while (pos)
        {
            nItem = theListCtrl.GetNextSelectedItem(pos);
            nSubItem = theListCtrl.GetItemData(nItem);	
            pDataItem = pData->GetSubItemData(m_nCurItemIndex, nSubItem);
            if (pDataItem->AvgFrameRate > 0)
                BWCount[(int) (pDataItem->AvgBandWidth / BWRange)] ++;
        }
    }

    for (index = 0; index < BWNum; index ++)
        sum += BWCount[index];

    sum1 = 0;
    for (index = 0; index < BWNum; index ++)
    {
        sum1 += BWCount[index];
        BWPerc[index] = sum > 0 ? (double)sum1 / sum : 0.0;
    }	

    BW = 0.0;
    for (index = 0; index < BWNum; index++)
    {
        fprintf(fp, "%.2lf,%.2lf\n", BW/1024.0, 100*BWPerc[index]);
        BW +=BWRange;
    }
    fclose (fp);
}

void CRealListView::OnCdfJitterAll() 
{
    CdfJitterAllAndSelected(FALSE);
}

void CRealListView::OnCdfJitterSelected() 
{
    CdfJitterAllAndSelected(TRUE);
}

void CRealListView::CdfJitterAllAndSelected(int bSelected)
{
    int index;
    int StartItem = 0;
    int sum = 0;
    int sum1 = 0;

    double JitterRange = 50.0;
    int JitterNum = 61;
    int JitterCount[70];
    double JitterPerc[70];
    double Jitter;

    CFileDialog fDlg(FALSE, "csv", NULL, OFN_HIDEREADONLY | OFN_OVERWRITEPROMPT, "csv files (*.csv)|*.csv|all files (*.*)|*.*||", AfxGetApp()->GetMainWnd());


    if (fDlg.DoModal() != IDOK)
        return;

    CString file = fDlg.GetPathName();
    FILE *fp;
    fp = fopen(file, "w");
    if (fp == NULL)
        return;

    for (index = 0; index < JitterNum; index ++)
    {
        JitterCount[index] = 0;
        JitterPerc[index] = 0.0;
    }

    CRealTraceData *pData = GetDocument()->GetRealTraceData();
    if (! bSelected)
    {
        int NumItem = pData->GetSubItemNum(m_nCurItemIndex);
        for(index = 0; index < NumItem; index++)
        {
            CRealData* pDataItem = pData->GetSubItemData(m_nCurItemIndex, index);
            if (pDataItem->AvgJitter > 0.0 && pDataItem->AvgJitter < 3000.0)
                JitterCount[(int) (pDataItem->AvgJitter / JitterRange)] ++;
        }
    }
    else
    {
        CListCtrl& theListCtrl = GetListCtrl();
        POSITION pos = theListCtrl.GetFirstSelectedItemPosition();
        int nItem, nSubItem;
        CRealData* pDataItem;
        while (pos)
        {
            nItem = theListCtrl.GetNextSelectedItem(pos);
            nSubItem = theListCtrl.GetItemData(nItem);	
            pDataItem = pData->GetSubItemData(m_nCurItemIndex, nSubItem);
            if (pDataItem->AvgJitter > 0.0 && pDataItem->AvgJitter < 3000.0)
                JitterCount[(int) (pDataItem->AvgJitter / JitterRange)] ++;
        }
    }

    for (index = 0; index < JitterNum; index ++)
        sum += JitterCount[index];

    sum1 = 0;
    for (index = 0; index < JitterNum; index ++)
    {
        sum1 += JitterCount[index];
        JitterPerc[index] = sum > 0 ? (double)sum1 / sum : 0.0;
    }	

    Jitter = 0.0;
    for (index = 0; index < JitterNum; index++)
    {
        fprintf(fp, "%.2lf,%.2lf\n", Jitter, 100*JitterPerc[index]);
        Jitter +=JitterRange;
    }
    fclose (fp);
}


void CRealListView::OnEditDelete() 
{
    CListCtrl& theListCtrl = GetListCtrl();

    CRealTraceData *pData = GetDocument()->GetRealTraceData();
    int index = m_nCurItemIndex;
    if (index < 0 || index > pData->GetItemNum() || theListCtrl.GetSelectedCount() <= 0)
    {
        MessageBox("Select log files to delete", "Error");
        return;
    }

    int i, j;
    int num = pData->GetSubItemNum(index);
    int *index_map = new int [num];
    for (i=0; i<num; i++)
        index_map[i] = (int) theListCtrl.GetItemData(i);

    BOOL *selected = new BOOL [num];
    for (i=0; i<num; i++)
        selected[i] = FALSE;

    int nItem = -1;
    while ( 1 )
    {
        nItem = theListCtrl.GetNextItem(nItem, LVNI_SELECTED);
        if (nItem == -1)
            break;
        selected[nItem] = TRUE;
    }

    for (i=0; i<num; i++)
    {
        if (! selected[i])
            continue;
        pData->DeleteSubItem(index, index_map[i]); 
        for (j=0; j<num; j++)
        {
            if (index_map[j] > index_map[i])
                index_map[j] --;
        }
    }

    for (i=0; i<num; i++)
        theListCtrl.SetItemData(i, (DWORD) index_map[i]);

    for (i=num-1; i>=0; i--)
    {
        if (selected[i])
            theListCtrl.DeleteItem(i);
    }

    delete [] index_map;
    delete [] selected;
}

void CRealListView::OnCount() 
{
	// TODO: Add your command handler code here

	int count = 0;
	char str[25];

	CListCtrl& theListCtrl = GetListCtrl();

	POSITION pos = theListCtrl.GetFirstSelectedItemPosition();
	
	
    while (pos)
    {
      theListCtrl.GetNextSelectedItem(pos);
	  count++;
    }

	sprintf(str, "count is %d", count);
	MessageBox(str);

}

void CRealListView::OnExport() 
{
    CRealData *SubItemData;
	int i = 0;


    CFileDialog fDlg(FALSE, "csv", NULL, OFN_HIDEREADONLY | OFN_OVERWRITEPROMPT, 
                     "csv files (*.csv)|*.csv|all files (*.*)|*.*||", AfxGetApp()->GetMainWnd());

	
    if (fDlg.DoModal() != IDOK)
        return;

    CString file = fDlg.GetPathName();
    FILE *fp;
    fp = fopen(file, "w");
    if (fp == NULL)
        return;

    CRealTraceData *pData = GetDocument()->GetRealTraceData();     
    CListCtrl& theListCtrl = GetListCtrl();
	
	
	POSITION pos = theListCtrl.GetFirstSelectedItemPosition();

    if (pos == NULL)
    {
        int NumItem = pData->GetSubItemNum(m_nCurItemIndex);
        for (i = 0; i < NumItem; i++)
	    {
		    SubItemData = (CRealData *)pData->GetSubItemData(m_nCurItemIndex, i);
			    
		    fprintf(fp,"%s,", (LPCSTR)SubItemData->FileName);
		    fprintf(fp,"%s,", (LPCSTR)SubItemData->Location);   
		    fprintf(fp, "%s,", (LPCSTR)SubItemData->IPAddress);
		    fprintf(fp, "%s,", szCPUType[SubItemData->CPUType]);   
		    fprintf(fp, "%d,", SubItemData->Memory);
		    fprintf(fp, "%s,", szOSType[SubItemData->OSType]);   
		    fprintf(fp, "%s,", szNetConfig[SubItemData->NetConfig]);
		    fprintf(fp, "%d,", SubItemData->Time);   
		    fprintf(fp, "%s,", (LPCSTR)SubItemData->VideoName);
		    fprintf(fp, "%s,",  (LPCSTR)SubItemData->RealServerInfo);   
		    fprintf(fp, "%s,", (LPCSTR)SubItemData->RealCodec); 
		    fprintf(fp, "%s,", szTransProtocol[SubItemData->TransProtocol]);   	
		    fprintf(fp, "%f,", SubItemData->AvgBandWidth); 
		    fprintf(fp, "%f,", SubItemData->AvgFrameRate);   
		    fprintf(fp, "%f,", SubItemData->AvgJitter); 
		    fprintf(fp, "%f,", SubItemData->AvgCpuUsage);   
		    fprintf(fp, "%f\n", SubItemData->Quality);
	   	}
    }
    else
    {
        while (pos)
        {
          int nItem = theListCtrl.GetNextSelectedItem(pos);
	      int nSubItem = theListCtrl.GetItemData(nItem);	
	      
          CRealData* SubItemData = pData->GetSubItemData(m_nCurItemIndex, nSubItem);
    
		    fprintf(fp,"%s,", (LPCSTR)SubItemData->FileName);
		    fprintf(fp,"%s,", (LPCSTR)SubItemData->Location);   
		    fprintf(fp, "%s,", (LPCSTR)SubItemData->IPAddress);
		    fprintf(fp, "%s,", szCPUType[SubItemData->CPUType]);   
		    fprintf(fp, "%d,", SubItemData->Memory);
		    fprintf(fp, "%s,", szOSType[SubItemData->OSType]);   
		    fprintf(fp, "%s,", szNetConfig[SubItemData->NetConfig]);
		    fprintf(fp, "%d,", SubItemData->Time);   
		    fprintf(fp, "%s,", (LPCSTR)SubItemData->VideoName);
		    fprintf(fp, "%s,",  (LPCSTR)SubItemData->RealServerInfo);   
		    fprintf(fp, "%s,", (LPCSTR)SubItemData->RealCodec); 
		    fprintf(fp, "%s,", szTransProtocol[SubItemData->TransProtocol]);   	
		    fprintf(fp, "%f,", SubItemData->AvgBandWidth); 
		    fprintf(fp, "%f,", SubItemData->AvgFrameRate);   
		    fprintf(fp, "%f,", SubItemData->AvgJitter); 
		    fprintf(fp, "%f,", SubItemData->AvgCpuUsage);   
		    fprintf(fp, "%f\n", SubItemData->Quality);
	    }
    }
	fclose(fp);
}
