/**************************************************************************
**
** Copyright (C) Computer Science Department, Worcester Polytechnic Institute,
**                           All rights reserved.
**
** FILE NAME: RealTreeView.cpp
**
** DESCRIPTION: This program implements the methods of CRealTreeView class
**              
**
** AUTHOR: Zheng Zuo/Yubing Wang        March-2001
**
/**************************************************************************/


// RealTreeView.cpp : implementation file
//

#include "stdafx.h"
#include "RealData.h"
#include "RealDataView.h"
#include "RealTreeView.h"
#include "RealListView.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CRealTreeView

IMPLEMENT_DYNCREATE(CRealTreeView, CTreeView)

CRealTreeView::CRealTreeView()
{
    m_bInitialUpdated = FALSE;
    m_dwDefaultStyle =  WS_CHILD | WS_VISIBLE | TVS_HASLINES | TVS_LINESATROOT | TVS_HASBUTTONS | TVS_SHOWSELALWAYS;   
}

CRealTreeView::~CRealTreeView()
{
}

CRealDataDoc *CRealTreeView::GetDocument()
{
    return ((CRealDataView *) GetParent()->GetParent())->GetDocument();
}


BEGIN_MESSAGE_MAP(CRealTreeView, CTreeView)
	//{{AFX_MSG_MAP(CRealTreeView)
	ON_WM_CREATE()
	ON_NOTIFY_REFLECT(TVN_SELCHANGED, OnSelchanged)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CRealTreeView drawing

void CRealTreeView::OnDraw(CDC* pDC)
{
	CDocument* pDoc = GetDocument();
	// TODO: add draw code here
}

/////////////////////////////////////////////////////////////////////////////
// CRealTreeView diagnostics

#ifdef _DEBUG
void CRealTreeView::AssertValid() const
{
	CTreeView::AssertValid();
}

void CRealTreeView::Dump(CDumpContext& dc) const
{
	CTreeView::Dump(dc);
}
#endif //_DEBUG

/////////////////////////////////////////////////////////////////////////////
// CRealTreeView message handlers

int CRealTreeView::OnCreate(LPCREATESTRUCT lpCreateStruct) 
{
    if (CTreeView::OnCreate(lpCreateStruct) == -1)
        return -1;

    return 0;
}

void CRealTreeView::OnInitialUpdate() 
{
    CTreeView::OnInitialUpdate();

    if (! m_bInitialUpdated)
    {
        m_bInitialUpdated = TRUE;
        m_pTreeCtrl = &(GetTreeCtrl()); 
    }
    else
    {
        m_pTreeCtrl->DeleteAllItems();
    }

    m_hRootItem = m_pTreeCtrl->InsertItem("RealTracer", TVI_ROOT, TVI_LAST);
    m_pTreeCtrl->SetItemData(m_hRootItem, (DWORD)99999);

    HTREEITEM item;
    CRealTraceData *pData = GetDocument()->GetRealTraceData();
    int num = pData->GetItemNum();
    for (int i=0; i<num; i++)
    {
        item = m_pTreeCtrl->InsertItem(pData->GetItemName(i), m_hRootItem);
        m_pTreeCtrl->SetItemData(item, (DWORD)i);
    }

    m_hPreviousSelectedItem = NULL;

    m_pTreeCtrl->Expand(m_hRootItem, TVE_EXPAND);   

    //Set background color of treeview. TVM_SETBKCOLOR requires Version 4.71 or newer of Comctl32.dll.
    //You can get an update to this DLL by installing the newest service pack for your OS.
    m_pTreeCtrl->SendMessage(TVM_SETBKCOLOR, 0, RGB(240, 210, 170)); // change the background color
    LONG style = ::GetWindowLong(m_pTreeCtrl->m_hWnd, GWL_STYLE);
    ::SetWindowLong(m_pTreeCtrl->m_hWnd, GWL_STYLE, style & ~TVS_HASLINES);  // remove the style TVS_HASLINES
    ::SetWindowLong(m_pTreeCtrl->m_hWnd, GWL_STYLE, style); //add the style back

    ShowWindow(SW_SHOW);
    UpdateWindow();	

}

void CRealTreeView::AddItem(int index)
{
    CRealTraceData *pData = GetDocument()->GetRealTraceData();

    HTREEITEM item = m_pTreeCtrl->InsertItem(pData->GetItemName(index), m_hRootItem);
    m_pTreeCtrl->SetItemData(item, (DWORD)index);

    m_pTreeCtrl->Expand(m_hRootItem, TVE_EXPAND);   
}

void CRealTreeView::OnSelchanged(NMHDR* pNMHDR, LRESULT* pResult) 
{
    NM_TREEVIEW* pNMTreeView = (NM_TREEVIEW*)pNMHDR;
    *pResult = 0;

    HTREEITEM hSelectedItem = m_pTreeCtrl->GetSelectedItem();
    if (hSelectedItem == m_hPreviousSelectedItem)  //if same as last view, then don't need to ReplaceView
        return;

    m_hPreviousSelectedItem = hSelectedItem;

    int index = m_pTreeCtrl->GetItemData(hSelectedItem);
    CRealTraceData *pData = GetDocument()->GetRealTraceData();
    CRealListView *pListView = (CRealListView *) ((CSplitterWnd *) GetParent())->GetPane(0, 1);
    pListView->ChangeListView(index);
}

/*
void CRealTreeView::OnExport() 
{
	// TODO: Add your command handler code here
	CRealData *SubItemData;
	int i = 0;

    int index = m_pTreeCtrl->GetItemData(m_hPreviousSelectedItem);
    CRealTraceData *pData = GetDocument()->GetRealTraceData();
    if (index > pData->GetItemNum())
        return;

    CFileDialog fDlg(FALSE, "csv", NULL, OFN_HIDEREADONLY | OFN_OVERWRITEPROMPT, 
                     "csv files (*.csv)|*.csv|all files (*.*)|*.*||", AfxGetApp()->GetMainWnd());

	
    if (fDlg.DoModal() != IDOK)
        return;

    CString file = fDlg.GetPathName();
    FILE *fp;
    fp = fopen(file, "w");
    if (fp == NULL)
        return;

	int NumItem = pData->GetSubItemNum(index);

    for (i = 0; i < NumItem; i++)
	{
		SubItemData = (CRealData *)pData->GetSubItemData(index, i);
			
		fprintf(fp,"%s,", (LPCSTR)SubItemData->FileName);
		fprintf(fp,"%s,", (LPCSTR)SubItemData->Location);   
		fprintf(fp, "%s,", (LPCSTR)SubItemData->IPAddress);
		fprintf(fp, "%s,", szCPUType[SubItemData->CPUType]);   
		fprintf(fp, "%d,", SubItemData->Memory);
		fprintf(fp, "%s,", szOSType[SubItemData->OSType]);   
		fprintf(fp, "%s,", szNetConfig[SubItemData->NetConfig]);
		fprintf(fp, "%s,", (LPCSTR)SubItemData->Time);   
		fprintf(fp, "%s,", (LPCSTR)SubItemData->VideoName);
		fprintf(fp, "%s,",  (LPCSTR)SubItemData->RealServerInfo);   
		fprintf(fp, "%s,", (LPCSTR)SubItemData->RealCodec); 
		fprintf(fp, "%s,", szTransProtocol[SubItemData->TransProtocol]);   	
		fprintf(fp, "%f,", SubItemData->AvgBandWidth); 
		fprintf(fp, "%f,", SubItemData->AvgFrameRate);   
		fprintf(fp, "%f,", SubItemData->AvgJitter); 
		fprintf(fp, "%f,", SubItemData->AvgCpuUsage);   
		fprintf(fp, "%f\n", SubItemData->Quality);
		
	}
	fclose(fp);
}
*/

